"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatViewProvider = void 0;
const vscode = __importStar(require("vscode"));
const ws_1 = __importDefault(require("ws"));
const child_process_1 = require("child_process");
const git_apply_1 = require("./webview/utils/git-apply");
// import {  DiffHunk, applyHunk } from './webview/utils/robust-apply-hunk';
const robust_apply_diff_1 = require("./webview/utils/robust-apply-diff");
class ChatViewProvider {
    _extensionUri;
    static viewType = 'haxa-ai.chatView';
    _view;
    _ws;
    _fileWatcher;
    _lastMessageState = [];
    _workspaceWatchers = [];
    fileChangeLog = [];
    _workspaceId;
    _credentials = {};
    // WebSocket reconnection parameters
    _serverUrl = 'https://haxa.ai';
    _apiKey;
    _reconnectAttempts = 0;
    _maxReconnectAttempts = 10;
    _reconnectTimeout = 100; // Start with 0.1 second
    _reconnectTimer;
    _isReconnecting = false;
    _extensionVersion = 'Unknown';
    filesFinalState = new Map();
    constructor(_extensionUri) {
        this._extensionUri = _extensionUri;
        this._setupFileWatcher();
        this._setupWorkspaceFileWatcher();
    }
    setWorkspaceId(id) {
        this._workspaceId = id;
    }
    initialize() {
        console.log('[Haxa.AI] Initializing ChatViewProvider');
        const packageJson = require('../package.json');
        const version = packageJson.version;
        this._extensionVersion = version;
        // if api token present, connect to the websocket
        this._attemptReconnect();
        this._view?.webview.postMessage({ type: 'initialize', workspaceId: this._workspaceId });
    }
    async validateAtlassianCredentials(email, token, domain) {
        try {
            const response = await fetch(`https://${domain}/rest/api/3/myself`, {
                method: 'GET',
                headers: {
                    'Authorization': `Basic ${Buffer.from(`${email}:${token}`).toString('base64')}`,
                    'Accept': 'application/json'
                }
            });
            return response.status === 200;
        }
        catch (error) {
            console.error('Atlassian validation error:', error);
            return false;
        }
    }
    _setupWorkspaceFileWatcher() {
        // Dispose existing watchers
        this._workspaceWatchers.forEach(watcher => watcher.dispose());
        this._workspaceWatchers = [];
        // Create watchers for all workspace folders
        vscode.workspace.workspaceFolders?.forEach(folder => {
            const watcher = this._createFolderWatcher(folder);
            this._workspaceWatchers.push(watcher);
        });
        // Watch for workspace folder changes
        vscode.workspace.onDidChangeWorkspaceFolders(event => {
            // Remove watchers for removed folders
            event.removed.forEach(folder => {
                const index = this._workspaceWatchers.findIndex(w => w === this._workspaceWatchers.find(watcher => watcher === this._createFolderWatcher(folder)));
                if (index !== -1) {
                    this._workspaceWatchers[index].dispose();
                    this._workspaceWatchers.splice(index, 1);
                }
            });
            // Add watchers for new folders
            event.added.forEach(folder => {
                const watcher = this._createFolderWatcher(folder);
                this._workspaceWatchers.push(watcher);
            });
        });
    }
    _createFolderWatcher(folder) {
        const watcher = vscode.workspace.createFileSystemWatcher(new vscode.RelativePattern(folder, '**/*'), false);
        // Ignore patterns for common directories and files
        const ignorePatterns = [
            '**/node_modules/**',
            '**/.git/**',
            '**/dist/**',
            '**/build/**',
            '**/.next/**',
            '**/coverage/**',
            '**/out/**',
            '**/package-lock.json',
            '**/yarn.lock',
            '**/dist/**',
            '**/build/**',
            '**/tsconfig.tsbuildinfo',
            '**/*.log',
            '**/logs/**',
            '**/log/**',
            '**/tmp/**',
            '**/.tmp/**',
            '**/__pycache__/**',
            '**/*.git', // Added to ignore .git extension files
            '**/.git', // Added to ignore .git extension files
        ];
        const isIgnored = (path) => {
            // Normalize path separators
            const normalizedPath = path.replace(/\\/g, '/');
            return ignorePatterns.some(pattern => {
                // Convert glob pattern to regex
                const regexPattern = pattern
                    .replace(/\*\*/g, '.*')
                    .replace(/\*/g, '[^/]*')
                    .replace(/\//g, '\\/');
                return new RegExp(regexPattern).test(normalizedPath);
            });
        };
        this.fileChangeLog = [];
        watcher.onDidCreate(uri => {
            const relativePath = vscode.workspace.asRelativePath(uri, false);
            console.log('[Haxa.AI][chatViewProvider][onDidCreate][relativePath]', relativePath);
            if (!isIgnored(relativePath)) {
                this.filesFinalState.set(relativePath, 'upsert');
                // console.log(this.filesFinalState);
                this._view?.webview.postMessage({
                    type: 'fileChanges',
                    changes: Array.from(this.filesFinalState.entries())
                        .map(([path, event]) => ({ path, event }))
                });
            }
        });
        watcher.onDidDelete(uri => {
            const relativePath = vscode.workspace.asRelativePath(uri, false);
            console.log('[Haxa.AI][chatViewProvider][onDidDelete][relativePath]', relativePath);
            if (!isIgnored(relativePath)) {
                this.filesFinalState.set(relativePath, 'delete');
                // console.log(this.filesFinalState);
                this._view?.webview.postMessage({
                    type: 'fileChanges',
                    changes: Array.from(this.filesFinalState.entries())
                        .map(([path, event]) => ({ path, event }))
                });
            }
        });
        watcher.onDidChange(uri => {
            const workspaceFolder = vscode.workspace.getWorkspaceFolder(uri);
            if (!workspaceFolder) {
                // console.log(`Could not determine workspace folder for ${uri.fsPath}`);
                return;
            }
            // console.log('Workspace folder:', workspaceFolder);
            const relativePath = vscode.workspace.asRelativePath(uri, false);
            console.log('[Haxa.AI][chatViewProvider][onDidChange][relativePath]', relativePath);
            if (!isIgnored(relativePath)) {
                this.filesFinalState.set(relativePath, 'upsert');
                // console.log('this.filesFinalState:', this.filesFinalState);
                this._view?.webview.postMessage({
                    type: 'fileChanges',
                    changes: Array.from(this.filesFinalState.entries())
                        .map(([path, event]) => ({ path, event }))
                });
            }
        });
        return watcher;
    }
    _setupFileWatcher() {
        this._fileWatcher = vscode.workspace.createFileSystemWatcher(new vscode.RelativePattern(this._extensionUri, 'out/**'));
        this._fileWatcher.onDidChange(async (uri) => {
            if (uri.fsPath.endsWith('chat-webview.js')) {
                await new Promise(resolve => setTimeout(resolve, 300));
                this._reloadWebview();
            }
        });
    }
    _reloadWebview() {
        if (this._view) {
            this._view.webview.postMessage({ type: 'getState' });
            this._view.webview.html = this._getHtmlForWebview(this._view.webview);
            setTimeout(() => {
                if (this._lastMessageState.length > 0) {
                    this._view?.webview.postMessage({
                        type: 'restoreState',
                        messages: this._lastMessageState
                    });
                }
            }, 200);
        }
    }
    _resetReconnectParams() {
        this._reconnectAttempts = 0;
        this._reconnectTimeout = 100;
        this._isReconnecting = false;
        if (this._reconnectTimer) {
            clearTimeout(this._reconnectTimer);
            this._reconnectTimer = undefined;
        }
    }
    async _attemptReconnect() {
        if (!this._serverUrl || !this._apiKey || this._isReconnecting) {
            // console.log('no server, key, or reconnect attempt already in progress');
            return;
        }
        this._isReconnecting = true;
        if (this._reconnectAttempts >= this._maxReconnectAttempts) {
            vscode.window.showErrorMessage('Failed to reconnect to Haxa.AI after multiple attempts. Please try reconnecting manually.');
            this._resetReconnectParams();
            return;
        }
        // console.log(`Attempting to reconnect... Attempt ${this._reconnectAttempts + 1} of ${this._maxReconnectAttempts}`);
        this._reconnectTimer = setTimeout(() => {
            this._reconnectAttempts++;
            this.connect(this._apiKey);
            // Exponential backoff with max of 32 seconds
            this._reconnectTimeout = Math.min(Math.floor(this._reconnectTimeout * 1.25), 30000);
        }, this._reconnectTimeout);
    }
    async _sendMessageWithRetry(data, retryCount = 0) {
        const maxRetries = 5;
        const retryDelay = 2000;
        // console.log('Sending message:', data);
        try {
            if (this._ws?.readyState !== ws_1.default.OPEN) {
                throw new Error('WebSocket is not connected');
            }
            this._ws.send(JSON.stringify(data));
        }
        catch (error) {
            console.error('Failed to send message:', error);
            // try to reconnect if the connection is lost
            if (!this._isReconnecting) {
                this._attemptReconnect();
            }
            if (retryCount < maxRetries) {
                console.log(`Retrying message send... Attempt ${retryCount + 1} of ${maxRetries}`);
                await new Promise(resolve => setTimeout(resolve, retryDelay));
                await this._sendMessageWithRetry(data, retryCount + 1);
            }
            else {
                vscode.window.showErrorMessage('Failed to send message after multiple attempts');
                // this._view?.webview.postMessage({
                //     type: 'receiveMessage',
                //     message: {
                //         type: 'error',
                //         error: 'Failed to send message. Please check your connection and try again.'
                //     }
                // });
            }
        }
    }
    resolveWebviewView(webviewView, context, _token) {
        this._view = webviewView;
        webviewView.webview.options = {
            enableScripts: true,
            localResourceRoots: [
                vscode.Uri.joinPath(this._extensionUri, 'out')
            ]
        };
        webviewView.webview.html = this._getHtmlForWebview(webviewView.webview);
        const workspaceFolder = vscode.workspace.workspaceFolders?.[0].uri.fsPath;
        webviewView.webview.onDidReceiveMessage(async (data) => {
            console.log('[chatViewProvider][onDidReceiveMessage]', data);
            switch (data.type) {
                case 'authenticate':
                    vscode.commands.executeCommand('haxa-ai.authenticate');
                    break;
                case 'validateAtlassian':
                    try {
                        const isValid = await this.validateAtlassianCredentials(data.email, data.token, data.domain);
                        this._view?.webview.postMessage({
                            type: 'validateAtlassianResponse',
                            isValid
                        });
                    }
                    catch (error) {
                        this._view?.webview.postMessage({
                            type: 'validateAtlassianResponse',
                            error: String(error)
                        });
                    }
                    break;
                case 'credentialsUpdated':
                    // console.log('[credentialsUpdated] Received credentials:', data.credentials);
                    this._credentials = { ...this._credentials, ...data.credentials };
                    this._apiKey = this._credentials.apiKey;
                    // console.log('[credentialsUpdated] Updated credentials:', this._credentials);
                    const credentials = data.credentials;
                    if (credentials.apiKey && credentials.serverUrl) {
                        this._resetReconnectParams();
                        this.connect(credentials.apiKey);
                    }
                    this._view?.webview.postMessage({
                        type: 'credentials',
                        credentials: this._credentials
                    });
                    break;
                case 'api-request':
                    try {
                        // console.log('API request:', data.url, data.options);
                        const response = await fetch(data.url, data.options);
                        if (!response.ok) {
                            throw new Error(`HTTP error! status: ${response.status}`);
                        }
                        const responseData = await response.json();
                        this._view?.webview.postMessage({
                            requestId: data.requestId,
                            data: responseData
                        });
                    }
                    catch (error) {
                        // console.error('API request failed:', error);
                        this._view?.webview.postMessage({
                            requestId: data.requestId,
                            error: error instanceof Error ? error.message : 'Failed to complete request'
                        });
                    }
                    break;
                case 'reviewDiff':
                    // console.log('Reviewing diff', data);
                    const cmd = `git diff --unified=10 HEAD`;
                    const cwd = workspaceFolder;
                    const messageData = { command: 'reviewDiff', diff: '' };
                    (0, child_process_1.exec)(cmd, { cwd }, async (error, stdout, stderr) => {
                        if (error) {
                            console.error('Failed to get diff:', error);
                            console.error('Failed to get diff:', stderr);
                            vscode.window.showErrorMessage(`Failed to get diff: ${stderr}`);
                            return;
                        }
                        messageData.diff = stdout;
                        await this._sendMessageWithRetry(messageData);
                    });
                    break;
                case 'getCredentials':
                    this._view?.webview.postMessage({
                        type: 'credentials',
                        credentials: this._credentials
                    });
                    break;
                case 'robustApplyDiff':
                    console.log('[robustApplyDiff] Applying diff:', data);
                    try {
                        const pathToRead = `${workspaceFolder}/${data.path}`;
                        console.log('[robustApplyDiff][pathToRead]', pathToRead);
                        const fileBuffer = await vscode.workspace.fs.readFile(vscode.Uri.file(pathToRead));
                        const originalFileContent = Buffer.from(fileBuffer).toString('utf8');
                        console.log('[robustApplyDiff] Original File content:', originalFileContent);
                        const after = (0, robust_apply_diff_1.applyDiff)(originalFileContent, data.diff);
                        if (after.error) {
                            console.error('[robustApplyDiff][error]', after.error);
                            vscode.window.showErrorMessage(`Failed to apply diff: ${after.error}`);
                            break;
                        }
                        else {
                            const updatedFileLines = after.result;
                            const updatedFileContent = updatedFileLines.join('\n');
                            console.log('[robustApplyDiff][updatedFileContent]', updatedFileContent);
                            try {
                                await vscode.workspace.fs.writeFile(vscode.Uri.file(pathToRead), Buffer.from(updatedFileContent, 'utf8'));
                                vscode.window.showInformationMessage(`${data.path} updated`);
                            }
                            catch (error) {
                                console.error('[robustApplyDiff][error]', error);
                                vscode.window.showErrorMessage(`Failed to write file: ${error}`);
                            }
                        }
                    }
                    catch (error) {
                        console.error('[chatViewProvider][robustApplyDiff]', error);
                    }
                    break;
                // case 'readFile':
                //     // console.log('Reading file:', data.path);
                //     try {
                //         const fileContent = await vscode.workspace.fs.readFile(vscode.Uri.file(data.path));
                //         const content = Buffer.from(fileContent).toString('utf8');
                //         this._view?.webview.postMessage({
                //             type: 'readFileAnswer',
                //             status: 'success',
                //             path: data.path,
                //             fileContent: content});
                //     } catch (error) {
                //         console.error('Failed to read file:', error);
                //         this._view?.webview.postMessage({
                //             type: 'readFileAnswer',
                //             status: 'error',
                //             path: data.path,
                //             error: error
                //         });
                //     }
                //     break;
                case 'gitApply':
                    // console.log('[gitApply] Applying diff:', data);
                    if (!workspaceFolder) {
                        console.error('[gitApply] No workspace folder found');
                        return;
                    }
                    const gitApply = new git_apply_1.GitApply(workspaceFolder);
                    const result = gitApply.apply(data.diff);
                    if (result.success) {
                        //   console.log('[gitApply] Modified files:', result.modifiedFiles);
                        //   console.log('[gitApply] Statistics:', result.statistics);
                    }
                    else {
                        //   console.log('[gitApply] Errors occurred:', result.errors);
                    }
                case 'applyDiff':
                    // console.log('Received diff:', data);
                    const timestamp = Date.now().toString();
                    const tmpFile = `${workspaceFolder}/.haxa-${timestamp}.patch`;
                    // console.log('[applyDiff] Temporary file:', tmpFile);
                    const lines = data.text.split('\n').slice(0, 5);
                    let pathArg = '-p0';
                    for (const line of lines) {
                        if (line.match(/^\+\+\+\s+b\//)) {
                            pathArg = '-p1';
                            break;
                        }
                    }
                    const cwdDir = workspaceFolder;
                    // if there is no empty line in data.text, add one
                    if (!data.text.endsWith('\n')) {
                        data.text += '\n';
                    }
                    try {
                        await vscode.workspace.fs.writeFile(vscode.Uri.file(tmpFile), Buffer.from(data.text, 'utf8'));
                        // Apply the diff using git apply
                        const command = `git apply ${pathArg} -v -C1 --3way  --no-index --recount --unidiff-zero --ignore-whitespace --ignore-space-change --whitespace=fix ${tmpFile}`;
                        (0, child_process_1.exec)(command, { cwd: cwdDir }, (error, stdout, stderr) => {
                            if (error) {
                                vscode.window.showErrorMessage(`[applyDiff] Failed to apply diff. Try manually.`);
                                this._view?.webview.postMessage({
                                    type: 'receiveMessage',
                                    message: { type: 'error', error: `Failed to apply diff. Try manually.` }
                                });
                                return;
                            }
                            vscode.window.showInformationMessage('[applyDiff] Successfully applied the diff');
                        });
                    }
                    catch (error) {
                        vscode.window.showErrorMessage(`Error applying diff: ${error}`);
                    }
                    finally {
                        vscode.workspace.fs.delete(vscode.Uri.file(tmpFile));
                    }
                    break;
                case 'question':
                    const filesChanges = [];
                    for (const [path, event] of this.filesFinalState.entries()) {
                        if (event === 'upsert') {
                            try {
                                const absolutePath = `${workspaceFolder}/${path}`;
                                const fileContent = await vscode.workspace.fs.readFile(vscode.Uri.file(absolutePath));
                                filesChanges.push({ path, event, content: fileContent.toString() });
                            }
                            catch (error) {
                                console.error(`Failed to read file content for ${path}:`, error);
                            }
                        }
                        else {
                            filesChanges.push({ path, event, content: '' });
                        }
                    }
                    // console.log('[question:data]',data);
                    var messageData1 = { ...data };
                    // FIXME: only clear filesFinalState if message is sent successfully. Use promise
                    messageData1.filesChanges = filesChanges;
                    await this._sendMessageWithRetry(messageData1);
                    // FIXME: uncomment this line
                    this.filesFinalState.clear();
                    break;
                case 'clearHistory':
                    await this._sendMessageWithRetry({ command: 'clearHistory' });
                    break;
                case 'reindex':
                    // console.log('Reindexing workspace:', workspaceFolder);
                    const tmpZipFile = `${workspaceFolder}/.haxa-reindex.zip`;
                    // console.log('Temporary zip file:', tmpZipFile);
                    try {
                        // Create a zip archive of the workspace using git archive
                        const command = `git archive -o ${tmpZipFile} HEAD`;
                        (0, child_process_1.exec)(command, { cwd: workspaceFolder }, async (error, stdout, stderr) => {
                            if (error) {
                                console.error('Failed to create zip archive:', error);
                                vscode.window.showErrorMessage(`Failed to create zip archive: ${stderr}`);
                                return;
                            }
                            // Read the zip file and encode its content in base64
                            const zipContent = await vscode.workspace.fs.readFile(vscode.Uri.file(tmpZipFile));
                            const base64ZipContent = Buffer.from(zipContent).toString('base64');
                            // Send the base64-encoded zip content in the message
                            console.log('Sending reindex command with zip content');
                            await this._sendMessageWithRetry({ type: 'command', command: 'reindex', archive: base64ZipContent });
                            // Clean up the temporary zip file
                            await vscode.workspace.fs.delete(vscode.Uri.file(tmpZipFile));
                        });
                    }
                    catch (error) {
                        vscode.window.showErrorMessage(`Error creating zip archive: ${error}`);
                    }
                    break;
                case 'saveState':
                    this._lastMessageState = data.messages;
                    break;
                case 'requestReconnect':
                    // console.log('[requestReconnect] Reconnecting to Haxa.AI');
                    if (this._apiKey) {
                        // console.log('[requestReconnect] API Key is present. Reconnecting...');
                        this._resetReconnectParams();
                        this.connect(this._apiKey);
                    }
                    break;
            }
        });
    }
    connect(apiKey, serverUrl = 'https://haxa.ai') {
        this._serverUrl = serverUrl;
        this._apiKey = apiKey;
        const wsUrl = new URL(serverUrl);
        wsUrl.protocol = 'wss:';
        if (this._ws) {
            this._ws.removeAllListeners();
            this._ws.close();
        }
        // console.log('[Haxa.AI] Connecting to WebSocket:', wsUrl);
        // console.log(wsUrl.toString());
        // console.log(wsUrl);
        // console.log('[Haxa.AI] workspace:', vscode.workspace);
        const ws = `${wsUrl.toString()}ws?api_key=${apiKey}`;
        // console.log('WS: ',ws);
        const headers = {
            'X-API-Key': apiKey,
            'X-Jira-Project-Url': this._credentials.jiraProjectUrl || '',
            'X-Atlassian-Email': this._credentials.atlassianEmail || '',
            'X-Atlassian-Api-Token': this._credentials.atlassianApiToken || '',
            'X-Confluence-Space-Url': this._credentials.confluenceSpaceUrl || '', // Add this line
            'X-Workspace-Id': this._workspaceId || '',
            'X-Extension-Version': this._extensionVersion
        };
        this._ws = new ws_1.default(ws, { headers: headers });
        // Set up ping/pong for connection keepalive
        const pingInterval = setInterval(() => {
            if (this._ws?.readyState === ws_1.default.OPEN) {
                this._ws.ping();
            }
        }, 30000);
        this._ws.on('open', () => {
            // console.log('WebSocket connected');
            this._resetReconnectParams();
            // vscode.window.showInformationMessage('Connected to Haxa.AI');
            this._view?.webview.postMessage({ type: 'connected' });
        });
        this._ws.on('message', (data) => {
            try {
                const message = JSON.parse(data.toString());
                // console.log('WS received:', message);
                if (message && (message.type === 'error' || message.answer)) {
                    this._view?.webview.postMessage({
                        type: 'receiveMessage',
                        message
                    });
                }
            }
            catch (error) {
                // console.error('Failed to parse message:', error);
                this._view?.webview.postMessage({
                    type: 'receiveMessage',
                    message: {
                        type: 'error',
                        error: 'Failed to parse server response'
                    }
                });
            }
        });
        this._ws.on('close', (code, reason) => {
            // console.log(`WebSocket closed with code ${code} and reason: ${reason}`);
            clearInterval(pingInterval);
            this._view?.webview.postMessage({ type: 'disconnected' });
            if (!this._isReconnecting) {
                // vscode.window.showWarningMessage('Disconnected from Haxa.AI. Attempting to reconnect...');
                this._attemptReconnect();
            }
        });
        this._ws.on('error', (error) => {
            console.error('WebSocket error:', error);
            // vscode.window.showErrorMessage(`Haxa.AI Error: ${error.message}`);
            if (!this._isReconnecting) {
                this._attemptReconnect();
            }
        });
        this._ws.on('pong', () => {
            // console.log('Received pong from server');
        });
        this._ws.on('unexpected-response', (request, response) => {
            console.error('Unexpected WebSocket response:', response.statusCode);
            vscode.window.showErrorMessage(`Unexpected response from server: ${response.statusCode}`);
        });
    }
    _getHtmlForWebview(webview) {
        const scriptUri = webview.asWebviewUri(vscode.Uri.joinPath(this._extensionUri, 'out', 'chat-webview.js'));
        // Add timestamp to force reload
        const nonce = Date.now().toString();
        return `
            <!DOCTYPE html>
            <html lang="en">
            <head>
                <meta charset="UTF-8">
                <meta name="viewport" content="width=device-width, initial-scale=1.0">
                <title>Haxa.AI Chat</title>
            </head>
            <body>
                <div id="root"></div>
                <script src="${scriptUri}?v=${nonce}"></script>
                <script>
                    window.workspaceId = "${this._workspaceId || ''}";

                    window.credentials = ${this._credentials};
                    window.extensionVersion = "${this._extensionVersion}";
                </script>
            </body>
            </html>
        `;
    }
    dispose() {
        if (this._ws) {
            this._ws.removeAllListeners();
            this._ws.close();
        }
        if (this._fileWatcher) {
            this._fileWatcher.dispose();
        }
        this._workspaceWatchers.forEach(watcher => watcher.dispose());
        if (this._reconnectTimer) {
            clearTimeout(this._reconnectTimer);
        }
    }
}
exports.ChatViewProvider = ChatViewProvider;
//# sourceMappingURL=chatViewProvider.js.map