"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HaxaApi = void 0;
const vscode_1 = require("../vscode");
const vscode = (0, vscode_1.getVSCodeAPI)();
class HaxaApi {
    serverUrl;
    retryOptions;
    constructor(serverUrl = 'http://localhost:7001', retryOptions = {}) {
        this.serverUrl = serverUrl;
        this.retryOptions = {
            maxRetries: 3,
            backoffMs: 1000,
            maxBackoffMs: 5000,
            ...retryOptions
        };
    }
    getHeaders() {
        const headers = {
            'Content-Type': 'application/json',
            'X-API-Key': vscode.getState()?.apiKey || '',
        };
        return headers;
    }
    async request(endpoint, options = {}) {
        const url = `${this.serverUrl}${endpoint}`;
        console.log('HaxaApi#request', url, options);
        // Use VS Code's postMessage to make the request
        return new Promise((resolve, reject) => {
            const requestId = Math.random().toString(36).substring(7);
            // Setup message handler
            const messageHandler = (event) => {
                const message = event.data;
                if (message.requestId === requestId) {
                    window.removeEventListener('message', messageHandler);
                    if (message.error) {
                        reject(new Error(message.error));
                    }
                    else {
                        resolve(message.data);
                    }
                }
            };
            window.addEventListener('message', messageHandler);
            // Send request to extension host
            vscode.postMessage({
                type: 'api-request',
                requestId,
                url,
                options: {
                    ...options,
                    headers: {
                        ...this.getHeaders(),
                        ...options.headers,
                    },
                },
            });
        });
    }
    async listProjects() {
        return this.request('/projects');
    }
    async createProject(data) {
        console.log('HaxaApi#createProject', data);
        return this.request('/projects', {
            method: 'POST',
            body: JSON.stringify(data),
        });
    }
    async updateProject(uuid, data) {
        console.log('HaxaApi#updateProject', data);
        return this.request(`/projects/${uuid}`, {
            method: 'PUT',
            body: JSON.stringify(data),
        });
    }
    async deleteProject(uuid) {
        console.log('HaxaApi#deleteProject', uuid);
        await this.request(`/projects/${uuid}`, {
            method: 'DELETE',
        });
    }
}
exports.HaxaApi = HaxaApi;
//# sourceMappingURL=HaxaApi.js.map