"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.AtlassianCredentialsForm = void 0;
const react_1 = __importStar(require("react"));
const StateProvider_1 = require("../providers/StateProvider");
const vscode_1 = require("../vscode");
const AtlassianCredentialsForm = ({ credentialsManager, onCredentialsSubmit }) => {
    const vscode = (0, vscode_1.getVSCodeAPI)();
    const { state, updateState } = (0, StateProvider_1.useAppState)();
    const [credentials, setCredentials] = (0, react_1.useState)(() => {
        const saved = credentialsManager.get();
        return {
            atlassianEmail: saved.atlassianEmail,
            atlassianApiToken: saved.atlassianApiToken,
            jiraProjectUrl: saved.jiraProjectUrl,
            confluenceSpaceUrl: saved.confluenceSpaceUrl
        };
    });
    const [validationState, setValidationState] = (0, react_1.useState)({});
    const [isValidating, setIsValidating] = (0, react_1.useState)(false);
    const validateAtlassianCredentials = (0, react_1.useCallback)(async (email, token, projectUrl) => {
        if (!email || !token || !projectUrl) {
            return false;
        }
        try {
            const url = new URL(projectUrl);
            const domain = url.hostname;
            const response = await new Promise((resolve, reject) => {
                const messageHandler = (event) => {
                    const message = event.data;
                    if (message.type === 'validateAtlassianResponse') {
                        window.removeEventListener('message', messageHandler);
                        if (message.error) {
                            reject(new Error(message.error));
                        }
                        else {
                            resolve(message.isValid);
                        }
                    }
                };
                window.addEventListener('message', messageHandler);
                vscode.postMessage({
                    type: 'validateAtlassian',
                    email,
                    token,
                    domain
                });
            });
            return response;
        }
        catch (error) {
            console.error('Validation error:', error);
            return false;
        }
    }, []);
    const handleInputChange = (0, react_1.useCallback)((field, value) => {
        setCredentials(prev => ({ ...prev, [field]: value }));
        setValidationState({}); // Reset validation on input change
    }, []);
    const handleSubmit = (e) => {
        e.preventDefault();
        credentialsManager.save(credentials);
        vscode.postMessage({
            type: 'credentialsUpdated',
            credentials
        });
        onCredentialsSubmit?.(credentials);
    };
    (0, react_1.useEffect)(() => {
        let timeoutId;
        const validateInputs = async () => {
            const { atlassianEmail, atlassianApiToken, jiraProjectUrl } = credentials;
            if (atlassianEmail && atlassianApiToken && jiraProjectUrl) {
                setIsValidating(true);
                const isValid = await validateAtlassianCredentials(atlassianEmail, atlassianApiToken, jiraProjectUrl);
                setValidationState({
                    atlassianEmail: isValid,
                    atlassianApiToken: isValid,
                    jiraProjectUrl: isValid
                });
                setIsValidating(false);
            }
        };
        timeoutId = setTimeout(validateInputs, 500);
        return () => clearTimeout(timeoutId);
    }, [credentials.atlassianEmail, credentials.atlassianApiToken, credentials.jiraProjectUrl, validateAtlassianCredentials]);
    return (react_1.default.createElement("form", { onSubmit: handleSubmit },
        react_1.default.createElement("section", { className: "credentials-section atlassian-credentials" },
            react_1.default.createElement("h3", null, "Atlassian Access Credentials"),
            react_1.default.createElement("div", { className: "form-group" },
                react_1.default.createElement("label", { htmlFor: "atlassianEmail" },
                    "Atlassian Email [",
                    react_1.default.createElement("a", { href: "https://id.atlassian.com/manage-profile/email", target: "_blank", rel: "noopener noreferrer", className: "token-hint" }, "Get it here"),
                    "]"),
                react_1.default.createElement("input", { type: "email", id: "atlassianEmail", className: validationState.atlassianEmail !== undefined ?
                        (validationState.atlassianEmail ? 'valid' : 'invalid') : '', value: credentials.atlassianEmail || '', onChange: e => handleInputChange('atlassianEmail', e.target.value), disabled: isValidating })),
            react_1.default.createElement("div", { className: "form-group" },
                react_1.default.createElement("label", { htmlFor: "atlassianApiToken" },
                    " Atlassian API Token [",
                    react_1.default.createElement("a", { href: "https://id.atlassian.com/manage-profile/security/api-tokens", target: "_blank", rel: "noopener noreferrer", className: "token-hint" }, "Get it here"),
                    "]"),
                react_1.default.createElement("input", { type: "password", id: "atlassianApiToken", className: validationState.atlassianApiToken !== undefined ?
                        (validationState.atlassianApiToken ? 'valid' : 'invalid') : '', value: credentials.atlassianApiToken || '', onChange: e => handleInputChange('atlassianApiToken', e.target.value), disabled: isValidating })),
            react_1.default.createElement("div", { className: "form-group" },
                react_1.default.createElement("label", { htmlFor: "jiraProjectUrl" }, "Jira Project URL"),
                react_1.default.createElement("input", { type: "text", id: "jiraProjectUrl", className: validationState.jiraProjectUrl !== undefined ?
                        (validationState.jiraProjectUrl ? 'valid' : 'invalid') : '', value: credentials.jiraProjectUrl || '', onChange: e => handleInputChange('jiraProjectUrl', e.target.value), disabled: isValidating, placeholder: "ex.: https://your-domain.atlassian.net/jira/software/projects/PROJECT" })),
            react_1.default.createElement("div", { className: "form-group" },
                react_1.default.createElement("label", { htmlFor: "confluenceSpaceUrl" }, "Confluence Space URL"),
                react_1.default.createElement("input", { type: "text", id: "confluenceSpaceUrl", value: credentials.confluenceSpaceUrl || '', onChange: e => handleInputChange('confluenceSpaceUrl', e.target.value), placeholder: "https://your-domain.atlassian.net/wiki/spaces/SPACE" })),
            isValidating && react_1.default.createElement("div", { className: "validation-status" }, "Validating credentials..."),
            react_1.default.createElement("button", { type: "submit" }, "Save Atlassian Credentials"))));
};
exports.AtlassianCredentialsForm = AtlassianCredentialsForm;
//# sourceMappingURL=AtlassianCredentialsForm.js.map