"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatApp = void 0;
const react_1 = __importStar(require("react"));
const ChatComponents_1 = require("./ChatComponents");
const vscode_1 = require("../vscode");
const logo_svg_1 = __importDefault(require("../../../resources/logo.svg"));
const vscode = (0, vscode_1.getVSCodeAPI)();
const handleFileRead = (file) => {
    return new Promise((resolve) => {
        const reader = new FileReader();
        reader.onload = () => {
            resolve({
                name: file.name,
                type: file.type,
                content: reader.result
            });
        };
        reader.readAsDataURL(file);
    });
};
const handleFiles = async (fileList) => {
    const newFiles = await Promise.all(Array.from(fileList).map(handleFileRead));
    return newFiles;
};
const ChatApp = () => {
    const [version, setVersion] = react_1.default.useState('');
    const [isConnected, setIsConnected] = react_1.default.useState(false);
    const inputFormRef = (0, react_1.useRef)(null);
    const [messages, setMessages] = react_1.default.useState(() => {
        const state = vscode.getState();
        return state?.messages || [];
    });
    const messagesEndRef = (0, react_1.useRef)(null);
    const [isDragging, setIsDragging] = react_1.default.useState(false);
    const messagesContainerRef = (0, react_1.useRef)(null);
    const scrollToBottom = (behavior = 'smooth') => {
        if (messagesEndRef.current && messagesContainerRef.current) {
            const container = messagesContainerRef.current;
            const isAtBottom = container.scrollHeight - container.scrollTop - container.clientHeight <= 100;
            if (!isAtBottom || behavior === 'auto') {
                messagesEndRef.current.scrollIntoView({
                    behavior,
                    block: 'nearest',
                    inline: 'start'
                });
            }
        }
    };
    // Save state when messages change
    (0, react_1.useEffect)(() => {
        vscode.setState({ messages });
        vscode.postMessage({ type: 'saveState', messages });
        setVersion(window.extensionVersion || 'Unknown');
    }, [messages]);
    // Handle scrolling after messages update
    (0, react_1.useEffect)(() => {
        scrollToBottom();
    }, [messages]);
    // Restore scroll position after hot reload
    (0, react_1.useEffect)(() => {
        scrollToBottom('auto');
    }, []);
    (0, react_1.useEffect)(() => {
        const messageHandler = (event) => {
            const message = event.data;
            console.log('Received event:', message);
            switch (message.type) {
                case 'connected':
                    setIsConnected(true);
                    break;
                case 'disconnected':
                    setIsConnected(false);
                    break;
                case 'receiveMessage':
                    if (message.message.type === 'error') {
                        setMessages(prev => [...prev, {
                                content: message.message.error,
                                type: 'error'
                            }]);
                    }
                    else if (message.message.answer || message.message.message) {
                        setMessages(prev => [...prev, {
                                content: message.message.answer || message.message.message,
                                type: 'assistant',
                                messageType: message.message.type || 'answer',
                                sources: message.message.sources
                            }]);
                        scrollToBottom();
                    }
                    break;
                case 'restoreState':
                    if (message.messages) {
                        setMessages(message.messages);
                    }
                    break;
            }
        };
        window.addEventListener('message', messageHandler);
        return () => window.removeEventListener('message', messageHandler);
    }, []);
    const handleDragEnter = (e) => {
        e.preventDefault();
        e.stopPropagation();
        setIsDragging(true);
    };
    const handleDragLeave = (e) => {
        e.preventDefault();
        e.stopPropagation();
        if (e.currentTarget.contains(e.relatedTarget)) {
            return;
        }
        setIsDragging(false);
    };
    const handleDrop = async (e) => {
        e.preventDefault();
        e.stopPropagation();
        setIsDragging(false);
        if (e.dataTransfer.files) {
            const files = await handleFiles(e.dataTransfer.files);
            inputFormRef.current?.addFiles(files);
        }
    };
    const handleDragOver = (e) => {
        e.stopPropagation();
        e.preventDefault();
        e.dataTransfer.dropEffect = 'copy';
    };
    const handleSendMessage = (content, files, options = {}) => {
        const messageData = {
            content,
            type: 'user',
        };
        if (files?.length) {
            messageData.files = files;
        }
        vscode.postMessage({
            type: 'question',
            message: content,
            projectId: '1',
            files: files?.map(f => ({
                ...f,
            })),
            modelType: options.modelType,
        });
        // setMessages(prev => [...prev, { content, type: 'user' }]);
        // console.log('!!!messageData',messageData);
        setMessages(prev => [...prev, messageData]);
    };
    const handleClearHistory = () => {
        setMessages([]);
        // Also clear the state in VS Code's storage
        vscode.setState({ messages: [] });
        vscode.postMessage({ type: 'clearHistory' });
        vscode.postMessage({ type: 'saveState', messages: [] });
    };
    const handleReviewDiff = () => {
        vscode.postMessage({ type: 'reviewDiff' });
    };
    // console.log('!!!messages',messages);
    return (react_1.default.createElement("div", { className: `chat-container ${isDragging ? 'dragging' : ''}`, onDrop: handleDrop, onDragEnter: handleDragEnter, onDragOver: handleDragOver, onDragLeave: handleDragLeave },
        react_1.default.createElement("div", { className: "messages", ref: messagesContainerRef },
            messages.length === 0 && (react_1.default.createElement("div", { className: "empty-state" },
                react_1.default.createElement("div", { className: "empty-state-content" },
                    react_1.default.createElement("img", { src: logo_svg_1.default, alt: "Haxa.AI Logo", className: "empty-state-logo" }),
                    react_1.default.createElement("p", null, "Start a conversation with Haxa.AI"),
                    react_1.default.createElement("p", { className: "empty-state-hint" }, "Ask me anything about your project")))),
            messages.map((msg, index) => (react_1.default.createElement(ChatComponents_1.Message, { key: `${index}-${msg.content}`, content: msg.content, type: msg.type, messageType: msg.messageType, sources: msg.sources, files: msg.files }))),
            react_1.default.createElement("div", { ref: messagesEndRef }),
            isDragging && (react_1.default.createElement("div", { className: "global-dropzone" },
                react_1.default.createElement("span", null, "Drop files here")))),
        react_1.default.createElement(ChatComponents_1.StatusBar, { onClearHistory: handleClearHistory, onReviewDiff: handleReviewDiff, isConnected: isConnected, onReconnect: () => {
                console.log('[ChatApp.tsx] Reconnecting...');
                vscode.postMessage({ type: 'requestReconnect' });
            }, onReindex: () => {
                vscode.postMessage({ type: 'reindex' });
            } }),
        react_1.default.createElement(ChatComponents_1.InputForm, { isConnected: isConnected, ref: inputFormRef, onSendMessage: handleSendMessage })));
};
exports.ChatApp = ChatApp;
//# sourceMappingURL=ChatApp.js.map