"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeBlock = void 0;
const react_1 = __importDefault(require("react"));
const ColorizedCodeSnippet_1 = require("./ColorizedCodeSnippet");
const vscode_1 = require("../vscode");
const vscode = (0, vscode_1.getVSCodeAPI)();
const HunkInfo = ({ value }) => {
    return react_1.default.createElement("tr", { className: 'hunk-info' },
        react_1.default.createElement("td", { colSpan: 2 }, value));
};
const LineIntact = ({ value }) => {
    return react_1.default.createElement("tr", { className: 'line-intact' },
        react_1.default.createElement("td", { className: 'diff-indicator' }),
        react_1.default.createElement("td", null, value));
};
const LineAdded = ({ value }) => {
    const content = value.slice(1);
    return react_1.default.createElement("tr", { className: 'line-added' },
        react_1.default.createElement("td", { className: 'diff-indicator' }, "+"),
        react_1.default.createElement("td", null, content));
};
const LineRemoved = ({ value }) => {
    const content = value.slice(1);
    return react_1.default.createElement("tr", { className: 'line-removed' },
        react_1.default.createElement("td", { className: 'diff-indicator' }, "-"),
        react_1.default.createElement("td", null, content));
};
const FileInfoBefore = ({ value }) => {
    return react_1.default.createElement("tr", { className: 'file-info-before' },
        react_1.default.createElement("td", { colSpan: 2 }, value));
};
const FileInfoAfter = ({ value }) => {
    return react_1.default.createElement("tr", { className: 'file-info-after' },
        react_1.default.createElement("td", { colSpan: 2 }, value));
};
const FileInfo = ({ value }) => {
    const match = value.match(/^diff --git a\/(.+?) b\/(.+)$/);
    const before = match ? match[1] : '';
    const after = match ? match[2] : '';
    // if (!before || !after) {
    //   return null;
    // }
    if (before === '/dev/null') {
        return (react_1.default.createElement("tr", { className: 'file-info' },
            react_1.default.createElement("td", { colSpan: 2 },
                react_1.default.createElement("div", null,
                    "New File: ",
                    after))));
    }
    if (after === '/dev/null') {
        return (react_1.default.createElement("tr", { className: 'file-info' },
            react_1.default.createElement("td", { colSpan: 2 },
                react_1.default.createElement("div", null,
                    "Deleted: ",
                    before))));
    }
    if (before === after) {
        return (react_1.default.createElement("tr", { className: 'file-info' },
            react_1.default.createElement("td", { colSpan: 2 },
                react_1.default.createElement("div", null,
                    "File: ",
                    before))));
    }
    return (react_1.default.createElement("tr", { className: 'file-info' },
        react_1.default.createElement("td", { colSpan: 2 }, value)));
};
const detectLineComponent = (line) => {
    if (line.startsWith('diff --git a/')) {
        return FileInfo;
    }
    if (line.startsWith('--- a/')) {
        return FileInfoBefore;
    }
    if (line.startsWith('+++ b/')) {
        return FileInfoAfter;
    }
    if (line.startsWith('@@ ')) {
        return HunkInfo;
    }
    if (line.startsWith('+')) {
        return LineAdded;
    }
    if (line.startsWith('-')) {
        return LineRemoved;
    }
    return LineIntact;
};
const DiffView = ({ value }) => {
    const lines = value.split('\n');
    return (react_1.default.createElement("div", { className: 'diff-view-block' },
        react_1.default.createElement("table", { className: 'diff-view' },
            react_1.default.createElement("tbody", null, lines.map((line, index) => (react_1.default.createElement(detectLineComponent(line), { value: line, key: index }))))),
        react_1.default.createElement("div", { className: 'diff-apply-container' },
            react_1.default.createElement("button", { onClick: () => onApply(value), className: 'diff-apply-button' }, "Apply Changes"))));
};
function extractFileName(diffBody) {
    // Try to extract from index line
    const indexMatch = diffBody.match(/^index [0-9a-f.]+\s+[ab]\/(.+)$/m);
    if (indexMatch) {
        return indexMatch[1];
    }
    // Fallback to diff headers if index line parsing fails
    const fileMatch = diffBody.match(/^(?:---|\+\+\+) [ab]\/(.+)$/m);
    if (fileMatch) {
        return fileMatch[1];
    }
    return '';
}
const onApply = (diffBody) => {
    // console.log('[CodeBlock][onApply]', diffBody);
    // Extract the file path from the diff body
    const filePath = extractFileName(diffBody);
    console.log('[CodeBlock][onApply][filePath]', filePath);
    if (!filePath) {
        console.error('[CodeBlock][onApply] Could not extract file path from diff');
        return;
    }
    vscode.postMessage({
        type: 'robustApplyDiff',
        path: filePath,
        diff: diffBody
    });
};
const CodeBlock = ({ language, value }) => {
    console.log('[CodeBlock]', language, value);
    if (language === 'diff' || value.startsWith('diff --git ')) {
        console.log('[CodeBlock][DiffView]', value);
        return react_1.default.createElement("div", null,
            react_1.default.createElement("h2", null, "DiffView"),
            react_1.default.createElement(DiffView, { value: value }));
    }
    return react_1.default.createElement("div", null,
        react_1.default.createElement("h2", null, language),
        react_1.default.createElement(ColorizedCodeSnippet_1.ColorizedCodeSnippet, { value: value, language: language }));
};
exports.CodeBlock = CodeBlock;
//# sourceMappingURL=CodeBlock.js.map
