"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputForm = void 0;
const react_1 = __importStar(require("react"));
const AutoGrowingTextarea_1 = __importDefault(require("./AutoGrowingTextarea"));
const StateProvider_1 = require("../providers/StateProvider");
const react_2 = require("@iconify/react");
exports.InputForm = (0, react_1.forwardRef)(({ isConnected, onSendMessage }, ref) => {
    const { state, updateState } = (0, StateProvider_1.useAppState)();
    const [message, setMessage] = react_1.default.useState(state.inputForm?.message || '');
    const [files, setFiles] = react_1.default.useState(state.inputForm?.files ?? []);
    const [modelType, setModelType] = react_1.default.useState(state.inputForm?.modelType || 'Mini');
    react_1.default.useEffect(() => {
        updateState({ inputForm: { message, files: files ?? [], modelType } });
    }, [message, files, modelType]);
    const containerRef = react_1.default.useRef(null);
    const isResizingRef = (0, react_1.useRef)(false);
    const fileInputRef = react_1.default.useRef(null);
    const handleResizeStart = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        isResizingRef.current = true;
        document.addEventListener('mousemove', handleMouseMove);
        document.addEventListener('mouseup', handleResizeEnd);
    }, []);
    const handleMouseMove = (0, react_1.useCallback)((e) => {
        if (!containerRef.current || !isResizingRef.current)
            return;
        const newHeight = window.innerHeight - e.clientY;
        const formHeight = containerRef.current.querySelector('.form-content')?.clientHeight ?? 50;
        console.log('[InputForm][handleMouseMove][formHeight]', formHeight);
        // if (newHeight < formHeight || newHeight > window.innerHeight * 0.5) return;
        containerRef.current.style.height = `${newHeight}px`;
    }, []);
    const handleResizeEnd = (0, react_1.useCallback)(() => {
        isResizingRef.current = false;
        document.removeEventListener('mousemove', handleMouseMove);
        document.removeEventListener('mouseup', handleResizeEnd);
    }, []);
    const handleFileRead = (0, react_1.useCallback)((file) => {
        return new Promise((resolve) => {
            const reader = new FileReader();
            reader.onload = () => {
                resolve({
                    name: file.name,
                    type: file.type,
                    content: reader.result
                });
            };
            reader.readAsDataURL(file);
        });
    }, []);
    const handleSubmit = (e) => {
        e.preventDefault();
        if (message.trim() && isConnected) {
            onSendMessage(message.trim(), files || [], { modelType });
            setMessage('');
            setFiles(undefined);
        }
    };
    const handleFiles = (0, react_1.useCallback)(async (fileList) => {
        const newFiles = await Promise.all(Array.from(fileList || []).map(handleFileRead));
        setFiles(prev => [...(prev ?? []), ...newFiles]);
    }, [handleFileRead]);
    const handleFileInputChange = (0, react_1.useCallback)((e) => {
        const fileList = e.target.files;
        if (fileList) {
            handleFiles(fileList).catch(error => {
                console.error('Error handling files:', error);
            });
        }
    }, [handleFiles]);
    const handlePaste = (0, react_1.useCallback)((e) => {
        const items = e.clipboardData?.items;
        if (!items)
            return;
        const files = Array.from(items)
            .filter(item => item.kind === 'file')
            .map(item => item.getAsFile())
            .filter((file) => file !== null);
        if (files.length > 0) {
            e.preventDefault();
            handleFiles(files);
        }
    }, [handleFiles]);
    const removeFile = (0, react_1.useCallback)((index) => {
        setFiles(prev => (prev || []).filter((_, i) => i !== index));
    }, []);
    (0, react_1.useImperativeHandle)(ref, () => ({
        addFiles: (newFiles) => {
            setFiles(prev => [...(prev || []), ...(newFiles || [])]);
        },
    }));
    return (react_1.default.createElement("div", { ref: containerRef, className: "inputForm", id: "inputForm" },
        react_1.default.createElement("div", { className: "resize-handle", onMouseDown: handleResizeStart }),
        react_1.default.createElement("form", { onSubmit: handleSubmit, className: 'input-form' },
            react_1.default.createElement("div", { className: "form-content" },
                react_1.default.createElement("input", { type: "file", ref: fileInputRef, onChange: handleFileInputChange, multiple: true, hidden: true }),
                react_1.default.createElement("div", { className: "form-content__input" },
                    react_1.default.createElement(AutoGrowingTextarea_1.default, { value: message, onChange: (e) => setMessage(e.target.value), onPaste: handlePaste, placeholder: "Ask Haxa.AI", maxRows: 20 }),
                    react_1.default.createElement("div", { className: "form-footer" },
                        react_1.default.createElement("span", { className: 'input-form__footer__left' },
                            react_1.default.createElement("button", { type: "button", className: "attach-button", onClick: () => fileInputRef.current?.click() },
                                react_1.default.createElement(react_2.Icon, { icon: "codicon:attach", height: 16, width: 16 }))),
                        react_1.default.createElement("span", { className: 'input-form__footer__right' },
                            react_1.default.createElement("select", { value: modelType, onChange: (e) => setModelType(e.target.value), className: "hidden" },
                                react_1.default.createElement("option", { value: "Mini" }, "Normal"),
                                react_1.default.createElement("option", { value: "Mega" }, "Ultra")),
                            react_1.default.createElement("div", null,
                                react_1.default.createElement("button", { type: "submit", className: "send-button", disabled: !isConnected || !message.trim(), style: { padding: 0 } },
                                    react_1.default.createElement(react_2.Icon, { icon: "codicon:send", height: 16, width: 16 })))))),
                (files ?? []).length > 0 && (react_1.default.createElement("div", { className: "file-list" }, (files ?? []).map((file, index) => (react_1.default.createElement("div", { key: index, className: "file-item" },
                    file.type.startsWith('image/') ? (react_1.default.createElement("div", { className: "file-preview" },
                        react_1.default.createElement("img", { src: file.content, alt: file.name, className: "preview-thumbnail" }))) : (react_1.default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "16", height: "16", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2", strokeLinecap: "round", strokeLinejoin: "round" },
                        react_1.default.createElement("path", { d: "M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z" }),
                        react_1.default.createElement("polyline", { points: "13 2 13 9 20 9" }))),
                    react_1.default.createElement("span", { className: "file-name" }, file.name),
                    react_1.default.createElement("button", { type: "button", onClick: () => removeFile(index), className: "remove-file" }, "\u00D7"))))))))));
});
//# sourceMappingURL=InputForm.js.map