"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Message = void 0;
const react_1 = __importDefault(require("react"));
const react_markdown_1 = __importDefault(require("react-markdown"));
const CodeBlock_1 = require("./CodeBlock");
const vscode_1 = require("../vscode");
const remark_gfm_1 = __importDefault(require("remark-gfm"));
const logo_svg_1 = __importDefault(require("../../../resources/logo.svg"));
const react_2 = require("@iconify/react");
const FileList = ({ files }) => {
    if (!files || files.length === 0) {
        return null;
    }
    return (react_1.default.createElement("div", { className: "file-list" }, files.map((file, index) => (react_1.default.createElement("div", { key: index, className: "file-list-item" },
        react_1.default.createElement("span", null,
            file.type.startsWith('image/') ? (react_1.default.createElement("div", { className: "file-preview" },
                react_1.default.createElement("img", { src: file.content, alt: file.name, className: "preview-thumbnail" }))) : (react_1.default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "16", height: "16", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2", strokeLinecap: "round", strokeLinejoin: "round" },
                react_1.default.createElement("path", { d: "M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z" }),
                react_1.default.createElement("polyline", { points: "13 2 13 9 20 9" }))),
            react_1.default.createElement("div", null, file.name)))))));
};
const UserMessage = ({ content, files }) => {
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("hr", null),
        react_1.default.createElement("div", { className: "message user-message" },
            react_1.default.createElement("div", { className: "message-header" },
                react_1.default.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: 2, strokeLinecap: "round", strokeLinejoin: "round", className: "lucide lucide-circle-user-round" },
                    react_1.default.createElement("path", { d: "M18 20a6 6 0 0 0-12 0" }),
                    react_1.default.createElement("circle", { cx: "12", cy: "10", r: "4" }),
                    react_1.default.createElement("circle", { cx: "12", cy: "12", r: "10" })),
                react_1.default.createElement("span", null, "You")),
            react_1.default.createElement("div", { className: "markdown-content" },
                react_1.default.createElement(FileList, { files: files }),
                react_1.default.createElement(react_markdown_1.default, { components: markdownComponents, remarkPlugins: [remark_gfm_1.default] }, content)))));
};
const AssistantMessage = ({ content, files, sources, messageType }) => {
    const handleCopyToClipboard = () => {
        try {
            console.log('[AssistantMessage] Copying to clipboard');
            navigator.clipboard.writeText(content).then(() => {
                const vscode = (0, vscode_1.getVSCodeAPI)();
                vscode.postMessage({
                    type: 'notification',
                    message: 'Copied to clipboard'
                });
            }).catch(err => {
                console.error('Failed to copy text: ', err);
            });
        }
        catch (err) {
            console.error('Clipboard API not available', err);
        }
    };
    return messageType === "answer" ? (react_1.default.createElement("div", null,
        react_1.default.createElement("hr", null),
        react_1.default.createElement("div", { className: "message assistant-message" },
            react_1.default.createElement("div", { className: "message-header" },
                react_1.default.createElement("img", { src: logo_svg_1.default, alt: "Haxa.AI" }),
                react_1.default.createElement("span", null, "Haxa.AI"),
                react_1.default.createElement("button", { onClick: handleCopyToClipboard, className: "copy-to-clipboard-button", title: "Copy to Clipboard" },
                    react_1.default.createElement(react_2.Icon, { icon: 'codicon:copy', width: 16, height: 16 }))),
            react_1.default.createElement("div", { className: "markdown-content" },
                react_1.default.createElement(FileList, { files: files }),
                react_1.default.createElement(react_markdown_1.default, { components: markdownComponents, remarkPlugins: [remark_gfm_1.default] }, content)),
            sources?.map((source, index) => (react_1.default.createElement("div", { key: index, className: "source" },
                react_1.default.createElement(react_markdown_1.default, { components: markdownComponents, remarkPlugins: [remark_gfm_1.default] }, source.content))))))) : (react_1.default.createElement("p", { className: `system-message system-message-${messageType}` }, content));
};
const ErrorMessage = ({ content }) => {
    return (react_1.default.createElement("div", { className: "message error-message" },
        react_1.default.createElement("div", { className: "markdown-content" },
            react_1.default.createElement(react_markdown_1.default, { components: markdownComponents, remarkPlugins: [remark_gfm_1.default] }, content))));
};
// Markdown components configuration
const markdownComponents = {
    code({ node, inline, className, children, ...props }) {
        const match = /language-(\w+)/.exec(className || '');
        const language = match ? match[1] : '';
        if (!inline && language) {
            return (react_1.default.createElement(CodeBlock_1.CodeBlock, { language: language, value: String(children).replace(/\n$/, ''), ...props }));
        }
        return (react_1.default.createElement("code", { className: className, ...props }, children));
    },
    pre({ children, ...props }) {
        return react_1.default.createElement(react_1.default.Fragment, null, children);
    }
};
const Message = ({ content, type, messageType, sources, files }) => {
    if (type === 'error') {
        return react_1.default.createElement(ErrorMessage, { content: content });
    }
    if (type === 'user') {
        return react_1.default.createElement(UserMessage, { content: content, files: files });
    }
    return react_1.default.createElement(AssistantMessage, { content: content, files: files, sources: sources, messageType: messageType });
};
exports.Message = Message;
//# sourceMappingURL=Message.js.map