"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const client_1 = require("react-dom/client");
const ChatApp_1 = require("./components/ChatApp");
const Settings_1 = require("./components/Settings");
const CredentialsProvider_1 = require("./providers/CredentialsProvider");
const CredentialsManager_1 = require("./utils/CredentialsManager");
const StateProvider_1 = require("./providers/StateProvider");
const vscode_1 = require("./vscode");
require("./Chat.css");
require("./InputForm.css");
require("./Tabs.css");
require("./DiffView.css");
require("./markdown.css");
const Tabs = ({ children }) => {
    const [activeTab, setActiveTab] = react_1.default.useState('chat');
    return (react_1.default.createElement("div", { className: "tabs-container" },
        react_1.default.createElement("div", { className: "tabs-header" },
            react_1.default.createElement("button", { className: `tab-button ${activeTab === 'chat' ? 'active' : ''}`, onClick: () => setActiveTab('chat') }, "Chat"),
            react_1.default.createElement("button", { className: `tab-button ${activeTab === 'settings' ? 'active' : ''}`, onClick: () => setActiveTab('settings') }, "Settings")),
        react_1.default.createElement("div", { className: "tab-content" }, react_1.default.Children.map(children, (child) => react_1.default.isValidElement(child) && (react_1.default.createElement("div", { style: {
                display: child.props.tabId === activeTab ? 'block' : 'none',
                height: '100%'
            } }, child))))));
};
const TabPanel = ({ tabId, children }) => {
    return react_1.default.createElement("div", { "data-tab-id": tabId }, children);
};
// Make sure the DOM is loaded
document.addEventListener('DOMContentLoaded', () => {
    const container = document.getElementById('root');
    if (!container) {
        throw new Error('#root element not found');
    }
    const vscode = (0, vscode_1.getVSCodeAPI)();
    const credentialsManager = new CredentialsManager_1.CredentialsManager(vscode, window.workspaceId || '');
    const root = (0, client_1.createRoot)(container);
    root.render(react_1.default.createElement(react_1.default.StrictMode, null,
        react_1.default.createElement(StateProvider_1.StateProvider, null,
            react_1.default.createElement("div", { className: "noselect" },
                react_1.default.createElement(CredentialsProvider_1.CredentialsProvider, { credentialsManager: credentialsManager },
                    react_1.default.createElement(Tabs, null,
                        react_1.default.createElement(TabPanel, { tabId: "chat" },
                            react_1.default.createElement(ChatApp_1.ChatApp, null)),
                        react_1.default.createElement(TabPanel, { tabId: "settings" },
                            react_1.default.createElement(Settings_1.Settings, null))))))));
});
//# sourceMappingURL=index.js.map