"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// git-diff-applier.test.ts
const git_diff_applier_1 = __importDefault(require("./git-diff-applier"));
console.error('**** GitDiffApplier', git_diff_applier_1.default);
describe('GitDiffApplier', () => {
    describe('applyDiff', () => {
        it('should add a new line in the middle of content', () => {
            const originalContent = "line1\nline2\nline3";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ -1,3 +1,4 @@
 line1
 line2
+new line
 line3`;
            const result = git_diff_applier_1.default.applyDiff(originalContent, diff);
            expect(result).toBe("line1\nline2\nnew line\nline3");
        });
        it('should handle empty files', () => {
            const emptyContent = "";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ -0,0 +1,2 @@
+first line
+second line`;
            const result = git_diff_applier_1.default.applyDiff(emptyContent, diff);
            expect(result).toBe("first line\nsecond line");
        });
        it('should handle multiple hunks in a single file', () => {
            const originalContent = "header\nline1\nline2\nline3\nfooter";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ -1,2 +1,3 @@
 header
+new header
 line1
@@ -4,2 +5,3 @@
 line3
+new footer
 footer`;
            const result = git_diff_applier_1.default.applyDiff(originalContent, diff);
            expect(result).toBe("header\nnew header\nline1\nline2\nline3\nnew footer\nfooter");
        });
        it('should handle different line endings', () => {
            const originalContent = "line1\r\nline2\r\nline3";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ -1,3 +1,4 @@
 line1
 line2
+new line
 line3`;
            const result = git_diff_applier_1.default.applyDiff(originalContent, diff);
            expect(result).toBe("line1\nline2\nnew line\nline3");
        });
        it('should handle removal of lines', () => {
            const originalContent = "line1\nline2\nline3\nline4";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ -1,4 +1,2 @@
 line1
-line2
-line3
 line4`;
            const result = git_diff_applier_1.default.applyDiff(originalContent, diff);
            expect(result).toBe("line1\nline4");
        });
        it('should throw error for invalid hunk header', () => {
            const originalContent = "line1\nline2";
            const diff = `diff --git a/file.txt b/file.txt
--- a/file.txt
+++ b/file.txt
@@ invalid header @@
 line1
+new line
 line2`;
            expect(() => {
                git_diff_applier_1.default.applyDiff(originalContent, diff);
            }).toThrow('Invalid hunk header: @@ invalid header @@');
        });
        it('should handle multiple files in a diff', () => {
            const originalContent = "content1\ncontent2";
            const diff = `diff --git a/file1.txt b/file1.txt
--- a/file1.txt
+++ b/file1.txt
@@ -1,2 +1,3 @@
 content1
+new content
 content2
diff --git a/file2.txt b/file2.txt
--- a/file2.txt
+++ b/file2.txt
@@ -1,2 +1,3 @@
 content1
+different content
 content2`;
            const result = git_diff_applier_1.default.applyDiff(originalContent, diff);
            expect(result).toBe("content1\nnew content\ncontent2");
        });
    });
});
//# sourceMappingURL=git-diff-applier.test.js.map